summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmheightfieldedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmheightfieldedit.h')
-rw-r--r--kpovmodeler/pmheightfieldedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmheightfieldedit.h b/kpovmodeler/pmheightfieldedit.h
index 8a32aa00..2b97b03a 100644
--- a/kpovmodeler/pmheightfieldedit.h
+++ b/kpovmodeler/pmheightfieldedit.h
@@ -39,12 +39,13 @@ class TQPushButton;
class PMHeightFieldEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMHeightFieldEdit with parent and name
*/
- PMHeightFieldEdit( TQWidget* parent, const char* name = 0 );
+ PMHeightFieldEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,12 +39,13 @@ class TQPushButton;
public:
/**
- * Creates a PMHeightFieldEdit with parent and name
+ * Creates a PMHeightFieldEdit with tqparent and name
*/